/*
	BlueTechButtonSymbol
    
    This class represents a MovieClip in Flash.  It basically
    just plays an animation when the mouse is moved over and off.
    The embed tag up top explicitly sets the SWF and symbol
    for Flex 2.  This would typically be done on frames
    instead of in a class.
    
    Created by Jesse R. Warden a.k.a. "JesterXL"
	jesterxl@jessewarden.com
	http://www.jessewarden.com
	http://www.universalmind.com
	
	This is release under a Creative Commons license. 
    More information can be found here:
    
    http://creativecommons.org/licenses/by/2.5/
*/

package com.jxl
{
	import flash.display.MovieClip;
	import flash.text.TextFormat;
	import flash.events.MouseEvent;
	import flash.events.Event;

	[Embed(source="/f9_button.swf", symbol="com.jxl.BlueTechButtonSymbol")]
	public class BlueTechButtonSymbol extends MovieClip
	{
		
		private static const LABEL_UP:String = "up";
		private static const LABEL_OVER_ON:String = "over on";
		private static const LABEL_OVER_OFF:String = "over off";
		
		private static const FRAME_OVER_ON_DONE:int = 20;
		private static const FRAME_OVER_OFF_DONE:int = 29;
		
		// define the label_mc as public so we can access it
		// it could be protected, but there was an earlier bug
		// in Flash that prevented authortime elements from
		// being protected / private
		public var label_mc:MovieClip;
		
		public function BlueTechButtonSymbol()
		{
			super();
			
			addEventListener(MouseEvent.MOUSE_OVER, onMouseOver);
			addEventListener(MouseEvent.MOUSE_OUT, onMouseOut);
			
			// stop, since our frame actions are removed
			stop();
		}
		
		public function setLabel(val:String):void
		{
			// set the animated TextField's text
			label_mc.label_txt.text = val.toUpperCase();
		}
		
		public function setEmbeddedFont(val:String):void
		{
			// not used, but if Flex embedded a different font,
			// it could then force the SWF to use it instead
			var _fmt:TextFormat = new TextFormat(val);
			label_mc.label_txt.embedFonts = true;
			label_mc.label_txt.setTextFormat(_fmt, 0, label_mc.label_txt.text.length);
		}
		
		protected function onMouseOver(event:MouseEvent):void
		{
			// play the over state
			gotoAndPlay(LABEL_OVER_ON);
			addEventListener(Event.ENTER_FRAME, onEnterFrame);
		}
		
		protected function onMouseOut(event:MouseEvent):void
		{
			// play the over off state
			gotoAndPlay(LABEL_OVER_OFF);
			addEventListener(Event.ENTER_FRAME, onEnterFrame);
		}
		
		protected function onEnterFrame(event:Event):void
		{
			// wait for the right frame to stop at
			if(currentFrame == FRAME_OVER_ON_DONE || currentFrame == FRAME_OVER_OFF_DONE)
			{
				stop();
				removeEventListener(Event.ENTER_FRAME, onEnterFrame);
			}
		}
		
	}
}

